@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "bdecoder.h"
 #include "bnode.h"
 #include <klocalizedstring.h>
@@ -48,7 +34,7 @@ BDecoder::~BDecoder()
 BNode *BDecoder::decode()
 {
     if (pos >= (Uint32)data.size())
-        return 0;
+        return nullptr;
 
     if (data[pos] == 'd') {
         return parseDict();
@@ -65,7 +51,7 @@ BNode *BDecoder::decode()
 
 BDictNode *BDecoder::decodeDict()
 {
-    BNode *n = 0;
+    BNode *n = nullptr;
     try {
         n = decode();
         if (n && n->getType() == BNode::DICT)
@@ -77,12 +63,12 @@ BDictNode *BDecoder::decodeDict()
         throw;
     }
 
-    return 0;
+    return nullptr;
 }
 
 BListNode *BDecoder::decodeList()
 {
-    BNode *n = 0;
+    BNode *n = nullptr;
     try {
         n = decode();
         if (n && n->getType() == BNode::LIST)
@@ -94,7 +80,7 @@ BListNode *BDecoder::decodeList()
         throw;
     }
 
-    return 0;
+    return nullptr;
 }
 
 BDictNode *BDecoder::parseDict()
