@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2012 by                                                 *
- *   Joris Guisson <joris.guisson@gmail.com>                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rpcmsgfactory.h"
 #include "announcereq.h"
@@ -53,7 +39,7 @@ RPCMsg::Ptr RPCMsgFactory::buildRequest(BDictNode *dict)
         throw bt::Error("Invalid request, arguments missing");
 
     RPCMsg::Ptr msg;
-    QString str = dict->getString(REQ, 0);
+    QString str = dict->getString(REQ, nullptr);
     if (str == "ping") {
         msg = RPCMsg::Ptr(new PingReq());
         msg->parse(dict);
@@ -119,7 +105,7 @@ RPCMsg::Ptr RPCMsgFactory::buildResponse(BDictNode *dict, dht::RPCMethodResolver
 
 RPCMsg::Ptr RPCMsgFactory::build(bt::BDictNode *dict, RPCMethodResolver *method_resolver)
 {
-    QString t = dict->getString(TYP, 0);
+    QString t = dict->getString(TYP, nullptr);
     if (t == REQ) {
         return buildRequest(dict);
     } else if (t == RSP) {
