@@ -1,30 +1,16 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "dndfile.h"
 #include <klocalizedstring.h>
-#include <util/log.h>
-#include <util/file.h>
-#include <util/error.h>
-#include <util/fileops.h>
-#include <util/sha1hash.h>
 #include <torrent/torrentfile.h>
+#include <util/error.h>
+#include <util/file.h>
+#include <util/fileops.h>
+#include <util/log.h>
+#include <util/sha1hash.h>
 
 namespace bt
 {
@@ -37,17 +23,18 @@ struct DNDFileHeader {
     Uint8 data_sha1[20];
 };
 
-DNDFile::DNDFile(const QString & path, const TorrentFile* tf, Uint32 chunk_size) : path(path)
+DNDFile::DNDFile(const QString &path, const TorrentFile *tf, Uint32 chunk_size)
+    : path(path)
 {
     last_size = tf->getLastChunkSize();
     first_size = chunk_size - tf->getFirstChunkOffset();
 }
 
-
 DNDFile::~DNDFile()
-{}
+{
+}
 
-void DNDFile::changePath(const QString & npath)
+void DNDFile::changePath(const QString &npath)
 {
     path = npath;
 }
@@ -88,9 +75,7 @@ void DNDFile::create()
     fptr.close();
 }
 
-
-
-Uint32 DNDFile::readFirstChunk(Uint8* buf, Uint32 off, Uint32 size)
+Uint32 DNDFile::readFirstChunk(Uint8 *buf, Uint32 off, Uint32 size)
 {
     File fptr;
     if (!fptr.open(path, "rb")) {
@@ -105,7 +90,7 @@ Uint32 DNDFile::readFirstChunk(Uint8* buf, Uint32 off, Uint32 size)
     return fptr.read(buf, size);
 }
 
-Uint32 DNDFile::readLastChunk(Uint8* buf, Uint32 off, Uint32 size)
+Uint32 DNDFile::readLastChunk(Uint8 *buf, Uint32 off, Uint32 size)
 {
     File fptr;
     if (!fptr.open(path, "rb")) {
@@ -120,7 +105,7 @@ Uint32 DNDFile::readLastChunk(Uint8* buf, Uint32 off, Uint32 size)
     return fptr.read(buf, size);
 }
 
-void DNDFile::writeFirstChunk(const Uint8* buf, Uint32 off, Uint32 size)
+void DNDFile::writeFirstChunk(const Uint8 *buf, Uint32 off, Uint32 size)
 {
     File fptr;
     if (!fptr.open(path, "r+b")) {
@@ -135,8 +120,7 @@ void DNDFile::writeFirstChunk(const Uint8* buf, Uint32 off, Uint32 size)
     fptr.write(buf, size);
 }
 
-
-void DNDFile::writeLastChunk(const Uint8* buf, Uint32 off, Uint32 size)
+void DNDFile::writeLastChunk(const Uint8 *buf, Uint32 off, Uint32 size)
 {
     File fptr;
     if (!fptr.open(path, "r+b")) {
