@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "encryptedauthenticate.h"
 
 #include <QRandomGenerator>
@@ -45,7 +31,7 @@ EncryptedAuthenticate::EncryptedAuthenticate(const net::Address &addr,
     mse::GeneratePublicPrivateKey(xa, ya);
     state = NOT_CONNECTED;
     buf_size = 0;
-    our_rc4 = 0;
+    our_rc4 = nullptr;
     vc_off = 0;
     dec_bytes = 0;
     crypto_select = 0;
@@ -201,10 +187,10 @@ void EncryptedAuthenticate::handlePadD()
 
     if (crypto_select & 0x00000001) { // plain_text selected
         delete our_rc4;
-        our_rc4 = 0;
+        our_rc4 = nullptr;
     } else if (crypto_select & 0x00000002) { // now it must be rc4 if not exit
         sock->setRC4Encryptor(our_rc4);
-        our_rc4 = 0;
+        our_rc4 = nullptr;
     } else { // we don't support anything else so error out
         onFinish(false);
         return;
@@ -234,7 +220,7 @@ void EncryptedAuthenticate::onReadyRead()
         case net::Socks::CONNECTED:
             // connection established, so get rid of socks shit
             delete socks;
-            socks = 0;
+            socks = nullptr;
             connected();
             if (sock->bytesAvailable() > 0)
                 onReadyRead();
