@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "socketmonitor.h"
 #include "downloadthread.h"
 #include "trafficshapedsocket.h"
@@ -38,8 +24,8 @@ class SocketMonitor::Private
 public:
     Private(SocketMonitor *p)
         : mutex(QMutex::Recursive)
-        , ut(0)
-        , dt(0)
+        , ut(nullptr)
+        , dt(nullptr)
         , next_group_id(1)
     {
         dt = new DownloadThread(p);
@@ -96,8 +82,8 @@ void SocketMonitor::Private::shutdown()
 
     delete ut;
     delete dt;
-    ut = 0;
-    dt = 0;
+    ut = nullptr;
+    dt = nullptr;
 }
 
 void SocketMonitor::lock()
