@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "httptracker.h"
 #include <config-ktorrent.h>
 
@@ -50,7 +36,7 @@ Uint16 HTTPTracker::proxy_port = 8080;
 
 HTTPTracker::HTTPTracker(const QUrl &url, TrackerDataSource *tds, const PeerID &id, int tier)
     : Tracker(url, tds, id, tier)
-    , active_job(NULL)
+    , active_job(nullptr)
     , failures(0)
     , supports_partial_seed_extension(false)
 {
@@ -76,7 +62,7 @@ void HTTPTracker::stop(WaitJob *wjob)
         reannounce_timer.stop();
         if (active_job) {
             active_job->kill();
-            active_job = 0;
+            active_job = nullptr;
             status = TRACKER_IDLE;
             requestOK();
         }
@@ -165,7 +151,7 @@ void HTTPTracker::onScrapeResult(KJob *j)
                     seeders = d->getInt(QByteArrayLiteral("complete"));
                     leechers = d->getInt(QByteArrayLiteral("incomplete"));
                     total_downloaded = d->getInt(QByteArrayLiteral("downloaded"));
-                    supports_partial_seed_extension = d->getValue(QByteArrayLiteral("downloaders")) != 0;
+                    supports_partial_seed_extension = d->getValue(QByteArrayLiteral("downloaders")) != nullptr;
                     Out(SYS_TRK | LOG_DEBUG) << "Scrape : leechers = " << leechers << ", seeders = " << seeders << ", downloaded = " << total_downloaded
                                              << endl;
                 } catch (...) {
@@ -260,7 +246,7 @@ bool HTTPTracker::updateData(const QByteArray &data)
     }
 
     BDecoder dec(data, false, i);
-    BNode *n = 0;
+    BNode *n = nullptr;
     try {
         n = dec.decode();
     } catch (...) {
@@ -367,7 +353,7 @@ void HTTPTracker::onKIOAnnounceResult(KJob *j)
 void HTTPTracker::onAnnounceResult(const QUrl &url, const QByteArray &data, KJob *j)
 {
     timer.stop();
-    active_job = 0;
+    active_job = nullptr;
     KIOAnnounceJob *st = (KIOAnnounceJob *)j;
     if (st->IsErrorPage() || (j->error() && data.size() == 0)) {
         QString err = error;
