@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005-2007 by Joris Guisson                              *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "upnpmcastsocket.h"
 #include <QFile>
@@ -66,7 +52,7 @@ UPnPMCastSocket::UPnPMCastSocket(bool verbose)
     : d(new UPnPMCastSocketPrivate(verbose))
 {
     QObject::connect(this, &UPnPMCastSocket::readyRead, this, &UPnPMCastSocket::onReadyRead);
-    QObject::connect(this, &UPnPMCastSocket::error, this, &UPnPMCastSocket::error);
+    QObject::connect(this, &UPnPMCastSocket::errorOccurred, this, &UPnPMCastSocket::error);
 
     for (Uint32 i = 0; i < 10; i++) {
         if (!bind(1900 + i, QUdpSocket::ShareAddress))
