@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "log.h"
 #include <cstdlib>
@@ -59,11 +45,11 @@ public:
 public:
     Private(Log *parent)
         : parent(parent)
-        , out(0)
-        , fptr(0)
+        , out(nullptr)
+        , fptr(nullptr)
         , to_cout(false)
         , filter(0)
-        , rotate_job(0)
+        , rotate_job(nullptr)
     {
     }
 
@@ -75,10 +61,10 @@ public:
     void cleanup()
     {
         delete out;
-        out = 0;
+        out = nullptr;
 
         delete fptr;
-        fptr = 0;
+        fptr = nullptr;
     }
 
     void setFilter(unsigned int f)
@@ -139,7 +125,7 @@ public:
 
         // only add stuff when we are not rotating the logs
         // this could result in the loss of some messages
-        if (!rotate_job && fptr != 0) {
+        if (!rotate_job && fptr != nullptr) {
             if (out)
                 *out << final << Qt::endl;
 
@@ -168,7 +154,7 @@ public:
             finishLine();
             QString file = fptr->fileName();
             fptr->close(); // close the log file
-            out->setDevice(0);
+            out->setDevice(nullptr);
             rotateLogs(file);
             logRotateDone();
         }
@@ -178,7 +164,7 @@ public:
     {
         fptr->open(QIODevice::WriteOnly);
         out->setDevice(fptr);
-        rotate_job = 0;
+        rotate_job = nullptr;
     }
 };
 
@@ -189,7 +175,7 @@ Log::Log()
 
 Log::~Log()
 {
-    qInstallMessageHandler(0);
+    qInstallMessageHandler(nullptr);
     delete priv;
 }
 
